declare module "MetaLibsVersion" {
    export enum Versions {
        V0_0_1 = "0.0.1",
        V0_1_0 = "0.1.0",
        V0_2 = "0.2",
        V0_3 = "0.3"
    }
    export const AllVersions: string[];
    export const CurrentVersion = Versions.V0_3;
}
declare module "Constants" {
    export const METAFRAME_JSON_FILE = "metaframe.json";
    export const METAPAGE_KEY_DEFINITION = "metapage/definition";
    export const METAPAGE_KEY_STATE = "metapage/state";
    export const URL_PARAM_DEBUG = "MP_DEBUG";
    export const VERSION: string;
}
declare module "v0_2/all" {
    import { Versions } from "MetaLibsVersion";
    export type MetaframePipeId = string;
    export type MetaframeId = string;
    export type MetapageId = string;
    export type MetaframeInputMap = {
        [key: string]: any;
    };
    export type MetaframePipeDefinition = {
        type?: string;
    };
    export interface MetapageDefinition {
        id?: MetapageId;
        version: Versions;
        metaframes: {
            [key: string]: MetaframeInstance;
        };
        meta?: MetapageMetadata;
    }
    export interface MetaframeDefinition {
        version?: Versions;
        inputs?: {
            [key: string]: MetaframePipeDefinition;
        };
        outputs?: {
            [key: string]: MetaframePipeDefinition;
        };
        metadata: MetaframeMetadata;
    }
    export type MetapageMetadata = {
        version?: string;
        layout?: MetapageMetadataLayout;
        name?: string;
    };
    export interface MetaframeInstanceAnonymous {
        url: string;
        metaframe: MetaframeDefinition;
        screenshotUrl?: string;
    }
    export interface PipeInput {
        metaframe: MetaframeId;
        source: MetaframePipeId;
        target: MetaframePipeId;
    }
    export interface PipeUpdateBlob {
        name: MetaframePipeId;
        value: any;
    }
    export interface MetaframeInstance extends MetaframeInstanceAnonymous {
        id: MetaframeId;
        inputs?: PipeInput[];
        state?: PipeUpdateBlob[];
        outputs?: PipeUpdateBlob[];
    }
    export type MetaframeMetadata = {
        version?: string;
        title?: string;
        author?: string;
        image?: string;
        descriptionUrl?: string;
        keywords?: string[];
        iconUrl?: string;
    };
    export type MetapageMetadataLayout = {
        version?: string;
        layouts?: {
            [key in MetapageVersionLayoutType]: MetapageVersionLayoutGrid;
        };
    };
    export type MetapageVersionLayoutGrid = {
        layout: ReactGridLayoutData[];
    };
    export type ReactGridLayoutData = {
        i?: string;
        x?: number;
        y?: number;
        w?: number;
        h?: number;
        minW?: number;
        maxW?: number;
        minH?: number;
        maxH?: number;
        isDraggable?: boolean;
        isResizable?: boolean;
    };
    export enum MetapageVersionLayoutType {
        gridlayout = "gridlayout"
    }
    export interface MetapageInstanceInputs {
        [key: string]: MetaframeInputMap;
    }
}
declare module "v0_3/all" {
    import { MetapageId } from "v0_2/all";
    import { MetapageDefinition as V0_2MetapageDefinition } from "v0_2/all";
    export { Versions, CurrentVersion, AllVersions } from "MetaLibsVersion";
    export type Url = string;
    export interface MetapageOptions {
        id?: MetapageId;
        color?: string;
    }
    export interface MetapageDefinition extends V0_2MetapageDefinition {
        plugins?: Url[];
    }
    export { MetapageInstanceInputs } from "v0_2/all";
    export { ReactGridLayoutData } from "v0_2/all";
    export { MetapageVersionLayoutGrid } from "v0_2/all";
    export { MetapageMetadataLayout } from "v0_2/all";
    export { MetapageVersionLayoutType } from "v0_2/all";
    export { MetaframeInstance } from "v0_2/all";
    export { PipeUpdateBlob } from "v0_2/all";
    export { PipeInput } from "v0_2/all";
    export { MetaframeInstanceAnonymous } from "v0_2/all";
    export { MetaframeMetadata } from "v0_2/all";
    export { MetapageMetadata } from "v0_2/all";
    export { MetaframeDefinition } from "v0_2/all";
    export { MetaframePipeDefinition } from "v0_2/all";
    export { MetaframeInputMap } from "v0_2/all";
    export { MetapageId } from "v0_2/all";
    export { MetaframeId } from "v0_2/all";
    export { MetaframePipeId } from "v0_2/all";
}
declare module "jsonrpc2" {
    export type JsonRpcVersion = "2.0";
    export type JsonRpcReservedMethod = string;
    export type JsonRpcId = number | string | void;
    export interface JsonRpcRequest<T> {
        jsonrpc: JsonRpcVersion;
        method: string;
        id: JsonRpcId;
        params?: T;
    }
    export interface JsonRpcNotification<T> extends JsonRpcResponse<T> {
        jsonrpc: JsonRpcVersion;
        params?: T;
    }
    export interface JsonRpcResponse<T> {
        jsonrpc: JsonRpcVersion;
        id: JsonRpcId;
    }
    export interface JsonRpcSuccess<T> extends JsonRpcResponse<T> {
        result: T;
    }
    export interface JsonRpcFailure<T> extends JsonRpcResponse<T> {
        error: JsonRpcError<T>;
    }
    export interface JsonRpcError<T> {
        code: number;
        message: string;
        data?: T;
    }
    export const PARSE_ERROR = -32700;
    export const INVALID_REQUEST = -32600;
    export const METHOD_NOT_FOUND = -32601;
    export const INVALID_PARAMS = -32602;
    export const INTERNAL_ERROR = -32603;
    export function isJsonRpcId(input: JsonRpcId | any): input is JsonRpcId;
}
declare module "v0_3/JsonRpcMethods" {
    import { MetaframeId, MetapageId, MetaframeInputMap, Versions } from "v0_3/all";
    import { JsonRpcRequest } from "jsonrpc2";
    export enum JsonRpcMethodsFromChild {
        InputsUpdate = "InputsUpdate",
        OutputsUpdate = "OutputsUpdate",
        SetupIframeClientRequest = "SetupIframeClientRequest",
        SetupIframeServerResponseAck = "SetupIframeServerResponseAck",
        PluginRequest = "SetupIframeServerPluginRequestResponseAck"
    }
    export enum JsonRpcMethodsFromParent {
        InputsUpdate = "InputsUpdate",
        MessageAck = "MessageAck",
        SetupIframeServerResponse = "SetupIframeServerResponse"
    }
    export enum OtherEvents {
        Message = "Message"
    }
    export interface SetupIframeServerResponseData {
        iframeId: MetaframeId;
        parentId: MetapageId;
        state: {
            inputs: MetaframeInputMap;
        };
        version: Versions;
        plugin: boolean;
    }
    export interface MinimumClientMessage<T> extends JsonRpcRequest<T> {
        iframeId: MetaframeId | undefined;
        parentId: MetapageId | undefined;
    }
    export interface SetupIframeClientAckData<T> extends MinimumClientMessage<T> {
        version: Versions;
    }
    export interface ClientMessageRecievedAck<T> {
        message: MinimumClientMessage<T>;
    }
    export enum ApiPayloadPluginRequestMethod {
        State = "metapage/state"
    }
    export interface ApiPayloadPluginRequest {
        method: ApiPayloadPluginRequestMethod;
    }
}
declare module "MetapageTools" {
    import { Versions } from "MetaLibsVersion";
    import { MetaframeInputMap, MetapageDefinition } from "v0_3/all";
    export const convertToCurrentDefinition: (def: any) => MetapageDefinition;
    export const merge: (current: MetaframeInputMap, newInputs: MetaframeInputMap) => boolean;
    export const getMatchingVersion: (version: string) => Versions;
    export const getUrlParam: (key: string) => string | null;
    export const getUrlParamDEBUG: () => boolean;
    export const existsAnyUrlParam: (k: string[]) => boolean;
    export const generateMetaframeId: (length?: number) => string;
    export const generateMetapageId: (length?: number) => string;
    export const generateNonce: (length?: number) => string;
    export const generateId: (length?: number) => string;
    export const log: (o: any, color?: string | undefined, backgroundColor?: string | undefined) => void;
    export const stringToRgb: (str: string) => string;
    export const hashCode: (str: string) => number;
    export const intToRGB: (i: number) => string;
    export function base64encode(arraybuffer: ArrayBuffer): string;
    export function base64decode(base64: string): ArrayBuffer;
}
declare module "Metaframe" {
    import { EventEmitter, ListenerFn } from "eventemitter3";
    import { Versions } from "MetaLibsVersion";
    import { MetaframeInputMap, MetaframePipeId, MetaframeId, MetapageId } from "v0_3/all";
    import { JsonRpcMethodsFromChild, SetupIframeServerResponseData } from "v0_3/JsonRpcMethods";
    enum MetaframeEvents {
        Input = "input",
        Inputs = "inputs",
        Message = "message"
    }
    export const isIframe: () => boolean;
    export class Metaframe extends EventEmitter<MetaframeEvents | JsonRpcMethodsFromChild> {
        static readonly version: string;
        static readonly INPUT = MetaframeEvents.Input;
        static readonly INPUTS = MetaframeEvents.Inputs;
        static readonly MESSAGE = MetaframeEvents.Message;
        _inputPipeValues: MetaframeInputMap;
        _outputPipeValues: MetaframeInputMap;
        _iframeId: MetaframeId | undefined;
        _parentId: MetapageId | undefined;
        _parentVersion: Versions | undefined;
        _isIframe: boolean;
        debug: boolean;
        ready: Promise<boolean>;
        color: string | undefined;
        plugin: MetaframePlugin | undefined;
        id: string | undefined;
        constructor();
        _resolver: ((val: boolean) => void) | undefined;
        _resolveSetupIframeServerResponse(params: SetupIframeServerResponseData): void;
        addListenerReturnDisposer(event: MetaframeEvents | JsonRpcMethodsFromChild, listener: ListenerFn<any[]>): () => void;
        log(o: any, color?: string, backgroundColor?: string): void;
        warn(o: any): void;
        error(err: any): void;
        logInternal(o: any, color?: string, backgroundColor?: string): void;
        dispose(): void;
        addListener(event: MetaframeEvents | JsonRpcMethodsFromChild, listener: ListenerFn<any[]>): this;
        onInput(pipeId: MetaframePipeId, listener: any): () => void;
        onInputs(listener: (m: MetaframeInputMap) => void): () => void;
        setInput(pipeId: MetaframePipeId, blob: any): void;
        setInputs(inputs: MetaframeInputMap): void;
        setInternalInputsAndNotify(inputs: MetaframeInputMap): void;
        getInput(pipeId: MetaframePipeId): any;
        getInputs(): MetaframeInputMap;
        getOutput(pipeId: MetaframePipeId): any;
        setOutput(pipeId: MetaframePipeId, updateBlob: any): void;
        setOutputs(outputs: MetaframeInputMap): void;
        getOutputs(): MetaframeInputMap;
        sendRpc(method: JsonRpcMethodsFromChild, params: any): void;
        onWindowMessage(e: any): void;
    }
    export class MetaframePlugin {
        _metaframe: Metaframe;
        constructor(metaframe: Metaframe);
        requestState(): void;
        onState(listener: (_: any) => void): () => void;
        getState(): any;
        setState(state: any): void;
        onDefinition(listener: (a: any) => void): () => void;
        setDefinition(definition: any): void;
        getDefinition(): any;
    }
}
declare module "Metapage" {
    import { EventEmitter, ListenerFn } from "eventemitter3";
    import { Versions } from "MetaLibsVersion";
    import { MetaframeDefinition, MetaframeInstance, PipeInput, MetapageOptions, MetaframeInputMap, MetaframePipeId, MetaframeId, MetapageId, MetapageInstanceInputs, MetapageDefinition } from "v0_3/all";
    import { JsonRpcMethodsFromParent, MinimumClientMessage, OtherEvents } from "v0_3/JsonRpcMethods";
    import { JsonRpcRequest } from "jsonrpc2";
    export enum MetapageEvents {
        Inputs = "inputs",
        Outputs = "outputs",
        State = "state",
        Definition = "definition",
        Error = "error"
    }
    export enum MetapageEventStateType {
        all = "all",
        delta = "delta"
    }
    export interface MetapageEventDefinition {
        definition: MetapageDefinition;
        metaframes: {
            [key: string]: IFrameRpcClient;
        };
        plugins?: {
            [key: string]: IFrameRpcClient;
        };
    }
    interface MetapageStatePartial {
        inputs: MetapageInstanceInputs;
        outputs: MetapageInstanceInputs;
    }
    export interface MetapageState {
        metaframes: MetapageStatePartial;
        plugins: MetapageStatePartial;
    }
    type Url = string;
    export const getLibraryVersionMatching: (version: string) => Versions;
    type MetaframeInputTargetsFromOutput = {
        metaframe: MetaframeId;
        pipe: MetaframePipeId;
    };
    export class Metapage extends EventEmitter<MetapageEvents | JsonRpcMethodsFromParent | OtherEvents> {
        static readonly version: string;
        static readonly DEFINITION = MetapageEvents.Definition;
        static readonly INPUTS = MetapageEvents.Inputs;
        static readonly OUTPUTS = MetapageEvents.Outputs;
        static readonly STATE = MetapageEvents.State;
        static readonly ERROR = MetapageEvents.Error;
        static from(metaPageDef: any, inputs?: any): Metapage;
        _id: MetapageId;
        _definition: MetapageDefinition | undefined;
        _state: MetapageState;
        _metaframes: {
            [key: string]: IFrameRpcClient;
        };
        _plugins: {
            [key: string]: IFrameRpcClient;
        };
        _pluginOrder: Url[];
        debug: boolean;
        _consoleBackgroundColor: string;
        _cachedInputLookupMap: {
            [key: string]: {
                [key: string]: MetaframeInputTargetsFromOutput[];
            };
        };
        _inputMap: {
            [key: string]: PipeInput[];
        };
        constructor(opts?: MetapageOptions);
        addListenerReturnDisposer(event: MetapageEvents | OtherEvents, listener: ListenerFn<any[]>): () => void;
        setDebugFromUrlParams(): Metapage;
        getState(): MetapageState;
        setState(newState: MetapageState): void;
        getStateMetaframes(): MetapageStatePartial;
        getDefinition(): MetapageDefinition | undefined;
        setDefinition(def: any, state?: MetapageState): Metapage;
        addPipe(target: MetaframeId, input: PipeInput): void;
        removeMetaframe(metaframeId: MetaframeId): void;
        removePlugin(url: Url): void;
        removeAll(): void;
        metaframes(): {
            [key: string]: IFrameRpcClient;
        };
        metaframeIds(): MetaframeId[];
        getMetaframeIds(): MetaframeId[];
        getMetaframes(): {
            [key: string]: IFrameRpcClient;
        };
        plugins(): {
            [key: string]: IFrameRpcClient;
        };
        pluginIds(): Array<Url>;
        getPluginIds(): Array<Url>;
        getMetaframe(id: MetaframeId): IFrameRpcClient;
        getPlugin(url: string): IFrameRpcClient;
        addMetaframe(metaframeId: MetaframeId, definition: MetaframeInstance): IFrameRpcClient;
        addPlugin(url: Url): IFrameRpcClient;
        dispose(): void;
        log(o: any, color?: string, backgroundColor?: string): void;
        error(err: any): void;
        emitErrorMessage(err: string): void;
        getInputsFromOutput(source: MetaframeId, outputPipeId: MetaframePipeId): MetaframeInputTargetsFromOutput[];
        isValidJSONRpcMessage(message: MinimumClientMessage<any>): boolean;
        setInput(iframeId: any, inputPipeId?: any, value?: any): void;
        setMetaframeClientInputAndSentClientEvent(iframeId: any, inputPipeId?: any, value?: any): void;
        setInputs(iframeId: any, inputPipeId?: any, value?: any): void;
        setOutputStateOnly(iframeId: any, inputPipeId?: any, value?: any): void;
        setInputStateOnly(iframeId: any, inputPipeId?: any, value?: any): void;
        _setStateOnly(isInputs: boolean, iframeId: any, inputPipeId?: any, value?: any): void;
        getMetaframeOrPlugin(key: string): IFrameRpcClient;
        onMessage(e: any): void;
        logInternal(o: any, color?: string, backgroundColor?: string): void;
    }
    class IFrameRpcClient extends EventEmitter<JsonRpcMethodsFromParent | MetapageEvents> {
        iframe: HTMLIFrameElement;
        id: MetaframeId;
        version: Versions | undefined;
        url: string;
        _color: string;
        _consoleBackgroundColor: string;
        _ready: Promise<boolean>;
        inputs: MetaframeInputMap;
        outputs: MetaframeInputMap;
        _disposables: (() => void)[];
        _rpcListeners: ((r: JsonRpcRequest<any>) => void)[];
        _loaded: boolean;
        _onLoaded: (() => void)[];
        _parentId: MetapageId;
        _debug: boolean;
        _sendInputsAfterRegistration: boolean;
        _definition: MetaframeDefinition | undefined;
        _plugin: boolean;
        _metapage: Metapage;
        constructor(metapage: Metapage, url: string, iframeId: MetaframeId, parentId: MetapageId, consoleBackgroundColor: string, debug?: boolean);
        addListenerReturnDisposer(event: JsonRpcMethodsFromParent | MetapageEvents, listener: ListenerFn<any[]>): () => void;
        setPlugin(): IFrameRpcClient;
        setMetapage(metapage: Metapage): IFrameRpcClient;
        bindPlugin(): Promise<void>;
        hasPermissionsState(): boolean;
        hasPermissionsDefinition(): boolean;
        getDefinitionUrl(): string;
        getDefinition(): Promise<MetaframeDefinition>;
        setInput(name: MetaframePipeId, inputBlob: any): void;
        _cachedEventInputsUpdate: {
            iframeId: string | undefined;
            inputs: MetaframeInputMap | undefined;
        };
        setInputs(maybeNewInputs: MetaframeInputMap): IFrameRpcClient;
        setOutput(pipeId: MetaframePipeId, updateBlob: any): void;
        _cachedEventOutputsUpdate: {
            iframeId: null;
            inputs: null;
        };
        setOutputs(maybeNewOutputs: MetaframeInputMap): void;
        onInputs(f: (m: MetaframeInputMap) => void): () => void;
        onInput(pipeName: MetaframePipeId, f: (_: any) => void): () => void;
        onOutputs(f: (m: MetaframeInputMap) => void): () => void;
        onOutput(pipeName: MetaframePipeId, f: (_: any) => void): () => void;
        dispose(): void;
        register(): void;
        registered(version: Versions): void;
        sendInputs(inputs: MetaframeInputMap): void;
        sendRpc(method: string, params: any): void;
        ack(message: any): void;
        log(o: any): void;
        logInternal(o: any): void;
        sendRpcInternal(method: string, params: any): void;
        _bufferMessages: any[] | undefined;
        _bufferTimeout: number | undefined;
        sendOrBufferPostMessage(message: any): void;
    }
}
declare module "v0_0_1/all" {
    import { Versions } from "MetaLibsVersion";
    export type MetaframePipeId = string;
    export type MetaframeId = string;
    export type MetapageId = string;
    export interface Pipe {
        source: PipeOutput;
        target: PipeInput;
    }
    export interface PipeOutput {
        id: MetaframeId;
        name: MetaframePipeId;
    }
    export interface PipeInput extends PipeOutput {
    }
    export type MetaframeMetadata = {
        version?: string;
        title?: string;
        author?: string;
        image?: string;
        descriptionUrl?: string;
        keywords?: string[];
        iconUrl?: string;
    };
    export interface MetaframeDefinition {
        version?: Versions;
        inputs?: MetaframePipeDefinition[];
        outputs?: MetaframePipeDefinition[];
        metadata?: MetaframeMetadata;
    }
    export interface MetapageDefinition {
        id?: MetapageId;
        version: Versions;
        iframes: {
            [key: string]: MetaframeInstance;
        };
        options?: any;
        pipes?: Pipe[];
        meta?: MetapageMetadata;
        v?: number;
    }
    export interface MetaframePipeDefinition extends DataBlob {
        name: MetaframePipeId;
    }
    export interface DataBlob {
        value: any;
        encoding?: DataEncoding;
        hash?: string;
        source?: DataSource;
        type?: string;
    }
    export enum DataEncoding {
        utf8 = "utf8",
        base64 = "base64",
        json = "json"
    }
    export enum DataSource {
        SourceUrl = "url",
        SourceInline = "inline"
    }
    export interface MetaframeInstanceAnonymous {
        url: string;
        metaframe: MetaframeDefinition;
        screenshotUrl?: string;
        updatedAt?: Date;
    }
    export interface MetaframeInstance extends MetaframeInstanceAnonymous {
        id: MetaframeId;
        inputs?: Array<PipeUpdateBlob>;
        outputs?: Array<PipeUpdateBlob>;
    }
    export interface PipeUpdateBlob extends DataBlob {
        name: MetaframePipeId;
    }
    export interface PipeInputBlob extends PipeUpdateBlob {
        iframeId?: MetaframeId;
        parentId?: MetapageId;
    }
    export interface PipeOutputBlob extends PipeInputBlob {
    }
    export interface MetapageMetadata {
        version?: string;
        layout?: MetapageMetadataLayout;
        name?: string;
    }
    export enum MetapageVersionLayoutType {
        gridlayout = "gridlayout"
    }
    export type MetapageMetadataLayout = {
        version?: string;
        layouts?: {
            [key in MetapageVersionLayoutType]: MetapageVersionLayoutGrid;
        };
    };
    export type MetapageVersionLayoutGrid = {
        layout: ReactGridLayoutData[];
    };
    export type ReactGridLayoutData = {
        i?: string;
        x?: number;
        y?: number;
        w?: number;
        h?: number;
        minW?: number;
        maxW?: number;
        minH?: number;
        maxH?: number;
        isDraggable?: boolean;
        isResizable?: boolean;
    };
}
declare module "v0_1_0/all" {
    import { Versions } from "MetaLibsVersion";
    export type MetaframePipeId = string;
    export type MetaframeId = string;
    export type MetapageId = string;
    export interface Pipe {
        source: PipeOutput;
        target: PipeInput;
    }
    export interface PipeOutput {
        id: MetaframeId;
        name: MetaframePipeId;
    }
    export interface PipeInput extends PipeOutput {
    }
    export type MetaframeMetadata = {
        version?: string;
        title?: string;
        author?: string;
        image?: string;
        descriptionUrl?: string;
        keywords?: string[];
        iconUrl?: string;
    };
    export interface MetaframeDefinition {
        version?: Versions;
        inputs?: MetaframePipeDefinition[];
        outputs?: MetaframePipeDefinition[];
        metadata?: MetaframeMetadata;
    }
    export interface MetapageDefinition {
        id?: MetapageId;
        version: Versions;
        iframes: {
            [key: string]: MetaframeInstance;
        };
        options?: any;
        pipes?: Pipe[];
        meta?: MetapageMetadata;
        v?: number;
    }
    export interface MetaframePipeDefinition extends DataBlob {
        name: MetaframePipeId;
    }
    export interface DataBlob {
        value: any;
        encoding?: DataEncoding;
        hash?: string;
        source?: DataSource;
        type?: string;
    }
    export enum DataEncoding {
        utf8 = "utf8",
        base64 = "base64",
        json = "json"
    }
    export enum DataSource {
        SourceUrl = "url",
        SourceInline = "inline"
    }
    export interface MetaframeInstanceAnonymous {
        url: string;
        metaframe: MetaframeDefinition;
        screenshotUrl?: string;
        updatedAt?: Date;
    }
    export interface MetaframeInstance extends MetaframeInstanceAnonymous {
        id: MetaframeId;
        inputs?: Array<PipeUpdateBlob>;
        outputs?: Array<PipeUpdateBlob>;
    }
    export interface PipeUpdateBlob extends DataBlob {
        name: MetaframePipeId;
    }
    export interface PipeInputBlob extends PipeUpdateBlob {
        iframeId?: MetaframeId;
        parentId?: MetapageId;
    }
    export interface PipeOutputBlob extends PipeInputBlob {
    }
    export interface MetapageMetadata {
        version?: string;
        layout?: MetapageMetadataLayout;
        name?: string;
    }
    export enum MetapageVersionLayoutType {
        gridlayout = "gridlayout"
    }
    export type MetapageMetadataLayout = {
        version?: string;
        layouts?: {
            [key in MetapageVersionLayoutType]: MetapageVersionLayoutGrid;
        };
    };
    export type MetapageVersionLayoutGrid = {
        layout: ReactGridLayoutData[];
    };
    export type ReactGridLayoutData = {
        i?: string;
        x?: number;
        y?: number;
        w?: number;
        h?: number;
        minW?: number;
        maxW?: number;
        minH?: number;
        maxH?: number;
        isDraggable?: boolean;
        isResizable?: boolean;
    };
}
